@@ -280,9 +280,12 @@ class BookmarkService {
 	 * @throws MultipleObjectsReturnedException
 	 * @throws UnsupportedOperation
 	 */
-	public function delete($id) {
+	public function delete($id): void {
 		$bookmark = $this->bookmarkMapper->find($id);
-		$this->treeMapper->deleteEntry(TreeMapper::TYPE_BOOKMARK, $bookmark->getId());
+		$parents = $this->treeMapper->findParentsOf(TreeMapper::TYPE_BOOKMARK, $id);
+		foreach ($parents as $parent) {
+			$this->treeMapper->deleteEntry(TreeMapper::TYPE_BOOKMARK, $bookmark->getId(), $parent->getId());
+		}
 	}
 
 	/**
@@ -338,7 +341,7 @@ class BookmarkService {
 		$rootFolder = $this->folderMapper->findRootFolder($userId);
 		$bookmarks = $this->treeMapper->findChildren(TreeMapper::TYPE_BOOKMARK, $rootFolder->getId());
 		foreach ($bookmarks as $bookmark) {
-			$this->treeMapper->deleteEntry(TreeMapper::TYPE_BOOKMARK, $bookmark->getId());
+			$this->treeMapper->deleteEntry(TreeMapper::TYPE_BOOKMARK, $bookmark->getId(), $rootFolder->getId());
 		}
 		$folders = $this->treeMapper->findChildren(TreeMapper::TYPE_FOLDER, $rootFolder->getId());
 		foreach ($folders as $folder) {
