@@ -107,64 +107,59 @@ export default {
 			throw err
 		}
 	},
-	[actions.CREATE_BOOKMARK]({ commit, dispatch, state }, data) {
+	async [actions.CREATE_BOOKMARK]({ commit, dispatch, state }, data) {
 		if (state.loading.bookmarks) return
 		commit(mutations.FETCH_START, { type: 'createBookmark' })
-		return axios
-			.post(url(state, '/bookmark'), {
+		try {
+			const response = await axios.post(url(state, '/bookmark'), {
 				url: data.url,
 				title: data.title,
 				description: data.description,
 				folders: data.folders && data.folders.map(parseInt),
 				tags: data.tags,
 			})
-			.then(response => {
-				const {
-					data: { item: bookmark, status },
-				} = response
-				if (status !== 'success') {
-					throw new Error(response.data.data.join('\n'))
-				}
-				commit(mutations.DISPLAY_NEW_BOOKMARK, false)
-				commit(mutations.ADD_BOOKMARK, bookmark)
-				commit(mutations.SET_BOOKMARK_COUNT, { folderId: -1, count: state.countsByFolder[-1] + 1 })
-				return dispatch(actions.OPEN_BOOKMARK, bookmark.id)
-			})
-			.catch(err => {
-				console.error(err)
-				commit(
-					mutations.SET_ERROR,
-					AppGlobal.methods.t('bookmarks', 'Failed to create bookmark')
-				)
-				throw err
-			})
-			.finally(() => {
-				commit(mutations.FETCH_END, 'createBookmark')
-			})
+			const {
+				data: { item: bookmark, status },
+			} = response
+			if (status !== 'success') {
+				throw new Error(response.data.data.join('\n'))
+			}
+			commit(mutations.DISPLAY_NEW_BOOKMARK, false)
+			commit(mutations.ADD_BOOKMARK, bookmark)
+			commit(mutations.SET_BOOKMARK_COUNT, { folderId: -1, count: state.countsByFolder[-1] + 1 })
+			commit(mutations.FETCH_END, 'createBookmark')
+			return dispatch(actions.OPEN_BOOKMARK, bookmark.id)
+		} catch (err) {
+			console.error(err)
+			commit(mutations.FETCH_END, 'createBookmark')
+			commit(
+				mutations.SET_ERROR,
+				AppGlobal.methods.t('bookmarks', 'Failed to create bookmark')
+			)
+			throw err
+		}
+
 	},
-	[actions.SAVE_BOOKMARK]({ commit, dispatch, state }, id) {
+	async [actions.SAVE_BOOKMARK]({ commit, dispatch, state }, id) {
 		commit(mutations.FETCH_START, { type: 'saveBookmark' })
-		return axios
-			.put(url(state, `/bookmark/${id}`), this.getters.getBookmark(id))
-			.then(response => {
-				const {
-					data: { status },
-				} = response
-				if (status !== 'success') {
-					throw new Error(response.data)
-				}
-			})
-			.catch(err => {
-				console.error(err)
-				commit(
-					mutations.SET_ERROR,
-					AppGlobal.methods.t('bookmarks', 'Failed to save bookmark')
-				)
-				throw err
-			})
-			.finally(() => {
-				commit(mutations.FETCH_END, 'saveBookmark')
-			})
+		try {
+			const response = await axios.put(url(state, `/bookmark/${id}`), this.getters.getBookmark(id))
+			const {
+				data: { status },
+			} = response
+			if (status !== 'success') {
+				throw new Error(response.data)
+			}
+			commit(mutations.FETCH_END, 'saveBookmark')
+		} catch (err) {
+			console.error(err)
+			commit(mutations.FETCH_END, 'saveBookmark')
+			commit(
+				mutations.SET_ERROR,
+				AppGlobal.methods.t('bookmarks', 'Failed to save bookmark')
+			)
+			throw err
+		}
 	},
 	async [actions.MOVE_BOOKMARK](
 		{ commit, dispatch, state },
@@ -187,15 +182,15 @@ export default {
 			if (response2.data.status !== 'success') {
 				throw new Error(response2.data)
 			}
+			commit(mutations.FETCH_END, 'moveBookmark')
 		} catch (err) {
 			console.error(err)
+			commit(mutations.FETCH_END, 'moveBookmark')
 			commit(
 				mutations.SET_ERROR,
 				AppGlobal.methods.t('bookmarks', 'Failed to move bookmark')
 			)
 			throw err
-		} finally {
-			commit(mutations.FETCH_END, 'moveBookmark')
 		}
 	},
 	[actions.OPEN_BOOKMARK]({ commit }, id) {
@@ -288,31 +283,29 @@ export default {
 
 	[actions.RENAME_TAG]({ commit, dispatch, state }, { oldName, newName }) {
 		commit(mutations.FETCH_START, { type: 'tag' })
-		return axios
-			.put(url(state, `/tag/${oldName}`), {
-				name: newName,
-			})
-			.then(response => {
-				const {
-					data: { status },
-				} = response
-				if (status !== 'success') {
-					throw new Error(response.data)
-				}
-				commit(mutations.RENAME_TAG, { oldName, newName })
-				return dispatch(actions.LOAD_TAGS)
-			})
-			.catch(err => {
-				console.error(err)
-				commit(
-					mutations.SET_ERROR,
-					AppGlobal.methods.t('bookmarks', 'Failed to create bookmark')
-				)
-				throw err
-			})
-			.finally(() => {
-				commit(mutations.FETCH_END, 'tag')
-			})
+		try {
+			const response = axios
+				.put(url(state, `/tag/${oldName}`), {
+					name: newName,
+				})
+			const {
+				data: { status },
+			} = response
+			if (status !== 'success') {
+				throw new Error(response.data)
+			}
+			commit(mutations.RENAME_TAG, { oldName, newName })
+			commit(mutations.FETCH_END, 'tag')
+			return dispatch(actions.LOAD_TAGS)
+		} catch (err) {
+			console.error(err)
+			commit(mutations.FETCH_END, 'tag')
+			commit(
+				mutations.SET_ERROR,
+				AppGlobal.methods.t('bookmarks', 'Failed to create bookmark')
+			)
+			throw err
+		}
 	},
 	[actions.LOAD_TAGS]({ commit, dispatch, state }) {
 		commit(mutations.FETCH_START, { type: 'tags' })
@@ -320,19 +313,18 @@ export default {
 			.get(url(state, '/tag'), { params: { count: true } })
 			.then(response => {
 				const { data: tags } = response
+				commit(mutations.FETCH_END, 'tags')
 				return commit(mutations.SET_TAGS, tags)
 			})
 			.catch(err => {
 				console.error(err)
+				commit(mutations.FETCH_END, 'tags')
 				commit(
 					mutations.SET_ERROR,
 					AppGlobal.methods.t('bookmarks', 'Failed to load tags')
 				)
 				throw err
 			})
-			.finally(() => {
-				commit(mutations.FETCH_END, 'tags')
-			})
 	},
 	[actions.DELETE_TAG]({ commit, dispatch, state }, tag) {
 		return axios
@@ -373,19 +365,18 @@ export default {
 				} = response
 				if (status !== 'success') throw new Error(data)
 				const folders = data
+				commit(mutations.FETCH_END, 'folders')
 				return commit(mutations.SET_FOLDERS, folders)
 			})
 			.catch(err => {
 				console.error(err)
+				commit(mutations.FETCH_END, 'folders')
 				commit(
 					mutations.SET_ERROR,
 					AppGlobal.methods.t('bookmarks', 'Failed to load folders')
 				)
 				throw err
 			})
-			.finally(() => {
-				commit(mutations.FETCH_END, 'folders')
-			})
 	},
 	[actions.DELETE_FOLDER]({ commit, dispatch, state }, id) {
 		return axios
@@ -451,18 +442,17 @@ export default {
 				if (status !== 'success') {
 					throw new Error(response.data)
 				}
+				commit(mutations.FETCH_END, 'saveFolder')
 			})
 			.catch(err => {
 				console.error(err)
+				commit(mutations.FETCH_END, 'saveFolder')
 				commit(
 					mutations.SET_ERROR,
 					AppGlobal.methods.t('bookmarks', 'Failed to create folder')
 				)
 				throw err
 			})
-			.finally(() => {
-				commit(mutations.FETCH_END, 'saveFolder')
-			})
 	},
 	[actions.OPEN_FOLDER_DETAILS]({ commit }, id) {
 		commit(mutations.SET_SIDEBAR, { type: 'folder', id })
@@ -486,15 +476,15 @@ export default {
 					bookmark: bookmark.id,
 				})
 			}
+			commit(mutations.FETCH_END, 'moveSelection')
 		} catch (err) {
 			console.error(err)
+			commit(mutations.FETCH_END, 'moveSelection')
 			commit(
 				mutations.SET_ERROR,
 				AppGlobal.methods.t('bookmarks', 'Failed to move parts of selection')
 			)
 			throw err
-		} finally {
-			commit(mutations.FETCH_END, 'moveSelection')
 		}
 	},
 	async [actions.DELETE_SELECTION]({ commit, dispatch, state }) {
@@ -507,15 +497,15 @@ export default {
 			for (const bookmark of state.selection.bookmarks) {
 				await dispatch(actions.DELETE_BOOKMARK, { id: bookmark.id })
 			}
+			commit(mutations.FETCH_END, 'deleteSelection')
 		} catch (err) {
 			console.error(err)
+			commit(mutations.FETCH_END, 'deleteSelection')
 			commit(
 				mutations.SET_ERROR,
 				AppGlobal.methods.t('bookmarks', 'Failed to delete parts of selection')
 			)
 			throw err
-		} finally {
-			commit(mutations.FETCH_END, 'deleteSelection')
 		}
 	},
 
@@ -579,20 +569,18 @@ export default {
 				if (bookmarks.length < BATCH_SIZE) {
 					commit(mutations.REACHED_END)
 				}
+				commit(mutations.FETCH_END, 'bookmarks')
 				return dispatch(actions.ADD_ALL_BOOKMARKS, bookmarks)
 			})
 			.catch(err => {
 				console.error(err)
+				commit(mutations.FETCH_END, 'bookmarks')
 				commit(
 					mutations.SET_ERROR,
 					AppGlobal.t('bookmarks', 'Failed to fetch bookmarks.')
 				)
 				throw err
 			})
-			.finally(() => {
-				if (canceled) return
-				commit(mutations.FETCH_END, 'bookmarks')
-			})
 	},
 
 	async [actions.SET_SETTING]({ commit, dispatch, state }, { key, value }) {
